use crate::controller::{AuthController, LicenseController, UserController};
use actix_web::web;

pub fn config(cfg: &mut web::ServiceConfig) {
    cfg.service(
        web::scope("/api/v1")
            .service(
                web::resource("/users")
                    .get(UserController::list_users)
                    .post(UserController::create_user),
            )
            .route("/users/me", web::get().to(UserController::get_current_user))
            .service(
                web::resource("/users/{user_id}")
                    .delete(UserController::delete_user)
                    .put(UserController::update_user),
            )
            .service(
                web::resource("/licenses")
                    .get(LicenseController::list_groups)
                    .post(LicenseController::create_license),
            )
            .service(
                web::resource("/licenses/{license_id}")
                    .delete(LicenseController::delete_license)
                    .put(LicenseController::update_license),
            )
            .route("/groups", web::post().to(LicenseController::create_group))
            .service(web::resource("/groups/{group_id}").delete(LicenseController::delete_group))
            .service(web::scope("/auth").route("/login", web::post().to(AuthController::login))),
    );
}
