use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(License::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(License::Id)
                            .uuid()
                            .not_null()
                            .primary_key()
                            .extra("DEFAULT gen_random_uuid()"),
                    )
                    .col(ColumnDef::new(License::Name).string().not_null())
                    .col(ColumnDef::new(License::Start).timestamp_with_time_zone())
                    .col(ColumnDef::new(License::End).timestamp_with_time_zone())
                    .col(ColumnDef::new(License::Amount).integer())
                    .col(ColumnDef::new(License::Key).string().not_null())
                    .col(ColumnDef::new(License::Note).string())
                    .col(ColumnDef::new(License::GroupId).uuid().not_null())
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-license-group_id")
                            .from(License::Table, License::GroupId)
                            .to(LicenseGroup::Table, LicenseGroup::Id)
                            .on_update(ForeignKeyAction::Cascade)
                            .on_delete(ForeignKeyAction::Cascade),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(License::Table).to_owned())
            .await
    }
}

#[derive(DeriveIden)]
enum License {
    Table,
    Id,
    Name,
    Start,
    End,
    Amount,
    Key,
    GroupId,
    Note,
}

#[derive(DeriveIden)]
enum LicenseGroup {
    Table,
    Id,
}
